/**
 * DeployAPIProvider
 * Provide CE Deploy Backend API
 */
import { APIProvider } from "@ess-ics/ce-ui-common";
import { node, arrayOf, oneOfType } from "prop-types";
import { apiContext } from "./DeployApi";
import env from "../config/env";

const propTypes = {
  /** Elements used as children */
  children: oneOfType([
    /** Array of elements. */
    arrayOf(node),
    /** One or more elements without array. */
    node
  ])
};

const apiOptions = {
  url: `${env.API_BASE_ENDPOINT}`,
  server: `${env.SERVER_ADDRESS}`,
  // Workaround for https://github.com/swagger-api/swagger-js/issues/1022
  // Empty body POST requests are sent with Content-Type text/plaintext
  // instead of no content type, or application/json
  requestInterceptor: (req) => {
    req.headers["Content-Type"] = "application/json";
    req.headers.accept = "application/json";
    window.req = req;
    return req;
  },
  responseInterceptor: (res) => {
    return res;
  }
};

export function DeployAPIProvider({ children }) {
  return (
    <APIProvider
      context={apiContext}
      options={apiOptions}
    >
      {children}
    </APIProvider>
  );
}

DeployAPIProvider.propTypes = propTypes;
