import { Stack, Typography } from "@mui/material";
import { InternalLink } from "@ess-ics/ce-ui-common";
import { getNoOfIOCs, isBatchJob } from "../JobUtils";
import { ActionTypeIconText } from "../JobIcons";
import { ACTION_TYPES } from "../JobData";
import { JobRevisionChip } from "../JobRevisionChip";

export const JobDetailsColumn = ({ job }) => (
  <Stack>
    <ActionTypeIconText action={job.action} />
    {!isBatchJob(job.type) ? (
      <Stack>
        <Stack
          flexDirection="row"
          gap={1}
          alignItems="center"
          flexWrap="wrap"
        >
          <InternalLink
            to={`/iocs/${job.iocId}`}
            label={`IOC Details, ${job.iocName}`}
          >
            {job.iocName}
          </InternalLink>
          {job.type === ACTION_TYPES.DEPLOY && (
            <JobRevisionChip
              gitReference={job.gitReference}
              gitProjectId={job.gitProjectId}
            />
          )}
        </Stack>
        <Stack
          flexDirection="row"
          gap={1}
          alignItems="baseline"
          flexWrap="wrap"
        >
          <InternalLink
            to={`/hosts/${job?.host?.hostId}`}
            label={`Host details, ${job.host?.hostName}`}
          >
            {job.host.hostName}
          </InternalLink>
          <Typography variant="body2">{job.host.network}</Typography>
        </Stack>
      </Stack>
    ) : (
      <Stack>
        <Typography variant="body2">{getNoOfIOCs(job.jobs)} IOCs</Typography>
        <Typography variant="body2">{job.jobs.length} Hosts</Typography>
      </Stack>
    )}
  </Stack>
);
