import { useState, useEffect } from "react";
import { Table, InternalLink } from "@ess-ics/ce-ui-common";
import { JobStatusColumn } from "./JobStatusColumn";
import { JobDetailsColumn } from "./JobDetailsColumn";
import { UserAvatar } from "../../common/User/UserAvatar";

const defaultColumns = [
  {
    field: "status",
    headerName: "Status",
    flex: 0.5
  },
  {
    field: "jobId",
    headerName: "Id",
    flex: 0.5
  },
  {
    field: "job",
    headerName: "Details",
    flex: 1
  },
  {
    field: "user",
    headerName: "User",
    align: "center",
    headerAlign: "center",
    flex: 0.5
  }
];

const shapeColumns = (customColumns) => {
  return customColumns.map((column) => {
    const mappedCol = defaultColumns.find((col) => col.field === column.field);
    return mappedCol ? { ...mappedCol, ...column } : null;
  });
};

const createTableRow = (job) => ({
  id: job.id,
  status: <JobStatusColumn {...{ job }} />,
  jobId: (
    <InternalLink
      to={`/jobs/${job?.id}`}
      label={`Job Details, ID ${job.id}`}
    >
      {`#${job.id}`}
    </InternalLink>
  ),
  job: <JobDetailsColumn {...{ job }} />,
  user: <UserAvatar username={job.createdBy} />
});

export const JobTable = ({
  jobs,
  customColumns,
  pagination,
  onPage,
  loading
}) => {
  const [columns, setColumns] = useState(null);

  useEffect(() => {
    if (customColumns) {
      setColumns(shapeColumns(customColumns));
    } else {
      setColumns(defaultColumns);
    }
  }, [customColumns, setColumns]);

  return (
    <>
      {columns ? (
        <Table
          columns={columns}
          rows={(columns && jobs?.map((job) => createTableRow(job))) || []}
          pagination={pagination}
          onPage={onPage}
          loading={loading}
          getEstimatedRowHeight={() => 260}
          getRowHeight={() => "auto"}
          sx={{
            "&.MuiDataGrid-root--densityCompact .MuiDataGrid-cell": {
              py: 1
            },
            "&.MuiDataGrid-root--densityStandard .MuiDataGrid-cell": {
              py: "15px"
            },
            "&.MuiDataGrid-root--densityComfortable .MuiDataGrid-cell": {
              py: "22px"
            }
          }}
        />
      ) : null}
    </>
  );
};
