import { useContext, useCallback } from "react";
import { userContext, useAPIMethod, usePolling } from "@ess-ics/ce-ui-common";
import { apiContext } from "../../../api/DeployApi";
import env from "../../../config/env";

export const TokenRenew = () => {
  const { user } = useContext(userContext);

  const client = useContext(apiContext);
  const {
    wrapper: renewToken,
    loading,
    abort
  } = useAPIMethod({
    fcn: client.apis.Authentication.tokenRenew,
    call: false
  });

  const renewTokenWhenLoggedIn = useCallback(() => {
    if (user) {
      renewToken();

      return () => {
        abort();
      };
    }
  }, [user, renewToken, abort]);

  usePolling(renewTokenWhenLoggedIn, loading, env.TOKEN_RENEW_INTERVAL, abort);

  return null;
};
