import {
  Brightness1,
  StopCircle,
  RadioButtonUnchecked,
  HelpOutline
} from "@mui/icons-material";

export const STATUS = {
  active: "active",
  disabled: "disabled",
  disabledAlert: "disabled alert",
  disabledWarning: "disabled warning",
  alert: "alert",
  warning: "warning",
  inactive: "inactive",
  inactiveAlert: "inactive alert",
  inactiveWarning: "inactive warning"
};

export const SEVERITY = {
  info: "info",
  alert: "error",
  warning: "warning"
};

export const statusesWithAlerts = [
  STATUS.alert,
  STATUS.warning,
  STATUS.disabledAlert,
  STATUS.disabledWarning,
  STATUS.inactiveAlert,
  STATUS.inactiveWarning
];

export const statusConfig = {
  [STATUS.active]: {
    title: "Active",
    icon: Brightness1
  },
  [STATUS.disabled]: {
    title: "Disabled",
    icon: StopCircle
  },
  [STATUS.disabledAlert]: {
    title: "Disabled",
    icon: StopCircle
  },
  [STATUS.disabledWarning]: {
    title: "Disabled",
    icon: StopCircle
  },
  [STATUS.alert]: {
    title: "Active",
    icon: Brightness1
  },
  [STATUS.warning]: {
    title: "Active",
    icon: Brightness1
  },
  [STATUS.inactive]: {
    title: "Inactive",
    icon: RadioButtonUnchecked
  },
  [STATUS.inactiveAlert]: {
    title: "Inactive",
    icon: RadioButtonUnchecked
  },
  [STATUS.inactiveWarning]: {
    title: "Inactive",
    icon: RadioButtonUnchecked
  },
  null: {
    title: "Unknown",
    icon: HelpOutline
  }
};

export const getStatus = (state, alert) => {
  let { isActive } = state;
  const isDeployed = !state.alertSeverity;
  const alertSeverity = alert?.alertSeverity?.toLowerCase();

  if (
    isActive &&
    (alertSeverity === undefined || alertSeverity === SEVERITY.info)
  ) {
    // Active status / running
    return STATUS.active;
  } else if (
    !isActive &&
    isDeployed &&
    (!alertSeverity || alertSeverity === SEVERITY.info)
  ) {
    // stopped/paused
    return STATUS.disabled;
  } else if (!isActive && isDeployed && alertSeverity === SEVERITY.alert) {
    return STATUS.disabledAlert;
  } else if (!isActive && isDeployed && alertSeverity === SEVERITY.warning) {
    return STATUS.disabledWarning;
  } else if (
    isActive &&
    alertSeverity !== undefined &&
    alertSeverity === SEVERITY.alert
  ) {
    // error
    return STATUS.alert;
  } else if (
    isActive &&
    alertSeverity !== undefined &&
    alertSeverity === SEVERITY.warning
  ) {
    // warning
    return STATUS.warning;
  } else if (
    isActive === false &&
    (!alertSeverity || alertSeverity === SEVERITY.info)
  ) {
    return STATUS.inactive;
  } else if (isActive === false && alertSeverity === SEVERITY.alert) {
    return STATUS.inactiveAlert;
  } else if (isActive === false && alertSeverity === SEVERITY.warning) {
    return STATUS.inactiveWarning;
  } else {
    // unknown fallback state
    return null;
  }
};
